@@ -1,31 +1,33 @@
-// $Id: Agent.h,v 1.4 1995/05/18 19:04:00 zeller Exp $
+// $Id: Agent.h,v 1.12 1997/04/25 06:34:17 zeller Exp $
 // Three-Channel Agent Interface 
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with the NORA Library -- see the file COPYING.LIB.
+// License along with the DDD Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// NORA is an experimental inference-based software development
-// environment. Contact nora@ips.cs.tu-bs.de for details.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
-#ifndef _Nora_Agent_h
-#define _Nora_Agent_h
+#ifndef _DDD_Agent_h
+#define _DDD_Agent_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -146,7 +148,7 @@ protected:
 
 private:
     bool _running;	      	// flag: is child still running?
-    bool _beingTerminated;   // flag: is child just being terminated?
+    bool _beingTerminated;      // flag: is child just being terminated?
 
     int _lastStatus;        	// Status after exiting
 
@@ -154,8 +156,10 @@ private:
     int _hangupTimeOut;    	// hangup TimeOut (in s)
     int _killTimeOut;      	// kill TimeOut (in s)
 
+protected:
     HandlerList handlers;   	// error handlers
 
+private:
     int to_child[2];		// pipes
     int to_parent[2];
     int to_parent_error[2];
@@ -310,6 +314,7 @@ public:
 
     // Duplicator
     Agent(const Agent& c);
+    virtual Agent *dup() const { return new Agent(*this); }
 
     // Destructor
     virtual ~Agent();
@@ -359,7 +364,7 @@ public:
 
     // Remove event handler
     void removeHandler(unsigned type, AgentHandlerProc proc,
-			       void *client_data = 0)
+		       void *client_data = 0)
     {
 	SignalBlocker sb(SIGCHLD);
 
@@ -395,15 +400,18 @@ public:
     void hasNewStatus(int status);
 
     // Resources
-    string path()		{ return _path;    }
-    pid_t pid()			{ return _pid;     }
-    int& terminateTimeOut()	{ return _terminateTimeOut; }
-    int& hangupTimeOut()	{ return _hangupTimeOut; }
-    int& killTimeOut()		{ return _killTimeOut; }
-    bool beingTerminated()	{ return _beingTerminated; }
-    int lastStatus()		{ return _lastStatus; }
+    string path() const		 { return _path;    }
+    pid_t pid()	const		 { return _pid;     }
+    int& terminateTimeOut()	 { return _terminateTimeOut; }
+    int& hangupTimeOut()	 { return _hangupTimeOut; }
+    int& killTimeOut()		 { return _killTimeOut; }
+    int terminateTimeOut() const { return _terminateTimeOut; }
+    int hangupTimeOut()	const    { return _hangupTimeOut; }
+    int killTimeOut()	const	 { return _killTimeOut; }
+    bool beingTerminated() const { return _beingTerminated; }
+    int lastStatus() const	 { return _lastStatus; }
 
-    string name()
+    string name() const
     {
 	ostrstream os;
 	os << path();
@@ -422,10 +430,11 @@ public:
     }
 
     // Debugging
-    virtual bool OK()
+    virtual bool OK() const
     {
 	return true;
     }
 };
 
-#endif
+#endif // _DDD_Agent_h
+// DON'T ADD ANYTHING BEHIND THIS #endif
