@@ -1,35 +1,37 @@
-// $Id: AgentM.h,v 1.3 1995/05/18 19:04:02 zeller Exp $
+// $Id: AgentM.h,v 1.9 1997/04/25 06:34:19 zeller Exp $
 // Agent Manager
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with the NORA Library -- see the file COPYING.LIB.
+// License along with the DDD Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// NORA is an experimental inference-based software development
-// environment. Contact nora@ips.cs.tu-bs.de for details.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
 // This class is used to perform process-wide actions;
 // especially terminating child agents upon exiting
 // and searching an agent with given pid
 
-#ifndef _Nora_AgentManager_h
-#define _Nora_AgentManager_h
+#ifndef _DDD_AgentManager_h
+#define _DDD_AgentManager_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -37,6 +39,7 @@
 
 
 #include <signal.h>
+#include "config.h"
 #include "TypeInfo.h"
 #include "bool.h"
 
@@ -44,7 +47,7 @@
 #define SIGCHLD SIGCLD
 #endif
 
-typedef void (*SignalProc)(int);
+typedef void (*SignalProc)(SIGHANDLERARGS);
 
 class Agent;
 
@@ -69,10 +72,10 @@ public:
     AgentManager(SignalProc new_chld_handler = SignalProc(SIG_IGN)):
 	first(0)
     {
-	// ignore "Broken Pipe" signals
+	// Ignore "Broken Pipe" signals
 	old_pipe_handler = SignalProc(signal(SIGPIPE, SignalProc(SIG_IGN)));
 
-	// catch "Death of child" signals
+	// Catch "Death of child" signals
 	old_chld_handler = SignalProc(signal(SIGCHLD, new_chld_handler));
     }
 
@@ -89,4 +92,6 @@ public:
     void commit();
 };
 
-#endif
+#endif // _DDD_AgentManager_h
+// DON'T ADD ANYTHING BEHIND THIS #endif
+
