@@ -1,27 +1,33 @@
-// $Id: AlignBox.h,v 1.3 1995/05/17 13:27:49 zeller Exp $
+// $Id: AlignBox.h,v 1.8 1997/04/25 06:34:23 zeller Exp $
 // Klasse AlignBox (Deklaration)
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the Free
-// Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// License along with the DDD Library -- see the file COPYING.LIB.
+// If not, write to the Free Software Foundation, Inc.,
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// 
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
-#ifndef _Nora_AlignBox_h
-#define _Nora_AlignBox_h
+#ifndef _DDD_AlignBox_h
+#define _DDD_AlignBox_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -75,7 +81,7 @@ protected:
 	CompositeBox::addChild(b);
 
 	// Groesse hinzufuegen (bzw. setzen, wenn erster)
-	if (nsons() == 1)
+	if (nchildren() == 1)
 	    setSize(b);     // erster Sohn: Groesse uebernehmen
 	else
 	    addSize(b);     // spaeterer Sohn: Groesse hinzufuegen
@@ -96,6 +102,12 @@ public:
     {}
 
     BoxSize corner() const { return _corner; }
+
+    AlignBox& operator += (Box *b)
+    {
+	addChild(b);
+	return *this;
+    }
 };
 
 
@@ -125,7 +137,8 @@ public:
 	AlignBox(initialSize, t) 
     {}
 
-    Box *dup() const { return new HAlignBox(*this); }
+    Box *dup() const  { return new HAlignBox(*this); }
+    Box *dup0() const { return new HAlignBox; }
 
     void addSize(Box *b);
 
@@ -169,7 +182,8 @@ public:
 	    AlignBox(initialSize, t)
     {}
 
-    Box *dup() const { return new VAlignBox(*this); }
+    Box *dup() const  { return new VAlignBox(*this); }
+    Box *dup0() const { return new VAlignBox; }
 
     void addSize(Box *b);
 
@@ -210,7 +224,8 @@ public:
 	AlignBox(initialSize, t)
     {}
 
-    Box *dup() const { return new UAlignBox(*this); }
+    Box *dup() const  { return new UAlignBox(*this); }
+    Box *dup0() const { return new UAlignBox; }
 
     void addSize(Box *b);
 
@@ -251,7 +266,8 @@ public:
 	AlignBox(initialSize, t)
     {}
 
-    Box *dup() const { return new TAlignBox(*this); }
+    Box *dup() const  { return new TAlignBox(*this); }
+    Box *dup0() const { return new TAlignBox; }
 
     void addSize(Box *b);
 
