@@ -1,27 +1,33 @@
-// $Id: DiagBox.h,v 1.2 1995/05/02 09:20:01 zeller Exp $
+// $Id: DiagBox.h,v 1.7 1997/04/25 06:35:41 zeller Exp $
 // Klasse DiagBox (Deklaration)
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the Free
-// Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+// License along with the DDD Library -- see the file COPYING.LIB.
+// If not, write to the Free Software Foundation, Inc.,
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// 
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
-#ifndef _Nora_DiagBox_h
-#define _Nora_DiagBox_h
+#ifndef _DDD_DiagBox_h
+#define _DDD_DiagBox_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -54,9 +60,9 @@ public:
 
     Box *dup() const { return new DiagBox(*this); }
 
-    virtual void _print(ostream& os, 
-			const BoxRegion& region, 
-			const BoxPrintGC& gc) const
+    virtual void _print(ostream&, 
+			const BoxRegion&, 
+			const BoxPrintGC&) const
     {
 	// do nothing
     }
