@@ -1,31 +1,33 @@
-// $Id: GraphEdge.h,v 1.3 1995/05/17 13:27:53 zeller Exp $
+// $Id: GraphEdge.h,v 1.11 1997/04/25 06:36:19 zeller Exp $
 // GraphEdge Class
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with the NORA Library -- see the file COPYING.LIB.
+// License along with the DDD Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// NORA is an experimental inference-based software development
-// environment. Contact nora@ips.cs.tu-bs.de for details.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
-#ifndef _Nora_GraphEdge_h
-#define _Nora_GraphEdge_h
+#ifndef _DDD_GraphEdge_h
+#define _DDD_GraphEdge_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -63,6 +65,7 @@ private:
     // maintained by Graph
     GraphEdge *next;		// For collectors
     GraphEdge *prev;
+    Graph *graph;
 
 protected:
     // Graphics
@@ -76,6 +79,20 @@ protected:
     // Dequeue from node lists
     void dequeue();
 
+    // Copy Constructor
+    GraphEdge(const GraphEdge& edge):
+        _from(0),
+        _to(0),
+	_hidden(edge._hidden),
+        _nextFrom(0),
+        _nextTo(0),
+        _prevFrom(0),
+        _prevTo(0),
+        next(0),
+        prev(0),
+	graph(0)
+    {}
+
 public:
     // Constructor
     GraphEdge(GraphNode *f, GraphNode *t):
@@ -83,9 +100,15 @@ public:
         _hidden(false),
         _nextFrom(0), _nextTo(0),
         _prevFrom(0), _prevTo(0),
-        next(0), prev(0)
+        next(0), prev(0), graph(0)
     {}
 
+    // Destructor
+    virtual ~GraphEdge() {}
+
+    // Duplication
+    virtual GraphEdge *dup() const = 0;
+
     // Resources
     GraphNode *from() const 	{ return _from; }
     GraphNode *to() const 	{ return _to; }
@@ -111,4 +134,5 @@ public:
 
 extern ostream& operator << (ostream& s, GraphEdge& e);
 
-#endif
+#endif // _DDD_GraphEdge_h
+// DON'T ADD ANYTHING BEHIND THIS #endif
