@@ -1,31 +1,33 @@
-// $Id: ListBox.h,v 1.3 1995/05/17 13:31:09 zeller Exp $
+// $Id: ListBox.h,v 1.9 1997/04/25 06:36:50 zeller Exp $
 // Klasse ListBox (Deklaration)
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with the NORA Library -- see the file COPYING.LIB.
+// License along with the DDD Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// NORA is an experimental inference-based software development
-// environment. Contact nora@ips.cs.tu-bs.de for details.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
-#ifndef _Nora_ListBox_h
-#define _Nora_ListBox_h
+#ifndef _DDD_ListBox_h
+#define _DDD_ListBox_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -90,11 +92,11 @@ protected:
 	CompositeBox(box), _last(0)
     {}
 
-    virtual void _draw(Widget w, 
-		       const BoxRegion& r, 
-		       const BoxRegion& exposed,
-		       GC gc, 
-		       bool context_selected) const
+    virtual void _draw(Widget, 
+		       const BoxRegion&, 
+		       const BoxRegion&,
+		       GC, 
+		       bool) const
     {
 	assert(0);  // ListBox kann nicht gezeichnet werden
 	::abort();
@@ -107,8 +109,8 @@ public:
     ListBox(Box *hd, ListBox *tl, char *t = "ListBox"):
 	CompositeBox(2, t), _last(tl->_last)
     {
-	thesize() = NoSize;
-	theextend() = NoExtend;
+	thesize()   = BoxSize();
+	theextend() = BoxExtend();
 
 	addChild(hd);
 	addChild(tl);
@@ -118,8 +120,8 @@ public:
     ListBox(char *t = "ListBox"):
 	CompositeBox(2, t), _last(this)
     {
-	thesize() = NoSize;
-	theextend() = NoExtend;
+	thesize()   = BoxSize();
+	theextend() = BoxExtend();
     }
 
     Box *dup() const { return new ListBox(*this); }
@@ -158,7 +160,8 @@ public:
     int length()
     {
 	const ListBox *t = this;
-	for (int i = 0; !t->isEmpty(); i++)
+	int i;
+	for (i = 0; !t->isEmpty(); i++)
 	    t = t->tail();
 	return i;
     }
@@ -167,7 +170,7 @@ public:
 
     bool isListBox() const { return true; }
 
-    void _print(ostream& os, const BoxRegion& r, const BoxPrintGC& gc) const
+    void _print(ostream&, const BoxRegion&, const BoxPrintGC&) const
     {
 	assert(0);  // ListBox kann nicht gedruckt werden
 	::abort();
