@@ -1,28 +1,30 @@
-// $Id: Map.h,v 1.1.1.1 1995/05/01 15:47:19 zeller Exp $
+// $Id: Map.h,v 1.6 1997/04/25 06:37:03 zeller Exp $
 // Map template
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Dorothea Luetkehaus (luetke@ips.cs.tu-bs.de).
+// Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>.
 // 
-// This file is part of DDD.
+// This file is part of the DDD Library.
 // 
-// DDD is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public
+// The DDD Library is free software; you can redistribute it and/or
+// modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// DDD is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU General Public License for more details.
+// See the GNU Library General Public License for more details.
 // 
-// You should have received a copy of the GNU General Public
-// License along with DDD -- see the file COPYING.
+// You should have received a copy of the GNU Library General Public
+// License along with the DDD Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// DDD is the GDB-based data display debugger.
-// Contact ddd@ips.cs.tu-bs.de for details.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
 //-----------------------------------------------------------------------------
 // Template fuer eine Map.
@@ -31,8 +33,8 @@
 //-----------------------------------------------------------------------------
 
 //-----------------------------------------------------------------------------
-#ifndef _Map_h
-#define _Map_h
+#ifndef _DDD_Map_h
+#define _DDD_Map_h
 
 #if defined(__GNUC_MINOR__) && (__GNUC_MINOR__ >= 5)
 #pragma interface
@@ -74,10 +76,10 @@ public:
     // 0, falls nicht vorhanden, sonst bel. enth. Key
     // simuliert 0-terminierte Liste
     Key first_key(MapRef& ln) const;
-    Key next_key(MapRef& ln) const;
+    static Key next_key(MapRef& ln);
     
     Contents* first(MapRef& ln) const;
-    Contents* next(MapRef& ln) const;
+    static Contents* next(MapRef& ln);
     
     inline int length()  const { return _length; }
 
@@ -236,7 +238,7 @@ Key Map<Key, Contents>::first_key(MapRef& ref) const {
 }
 
 template <class Key, class Contents>
-Key Map<Key, Contents>::next_key(MapRef& ref) const {
+Key Map<Key, Contents>::next_key(MapRef& ref) {
 //----------------------========-----
     // durchlaeuft 0-terminierte Liste
     if (ref == 0 ) {
@@ -266,7 +268,7 @@ Contents* Map<Key, Contents>::first(MapRef& ref) const {
 }
 
 template <class Key, class Contents>
-Contents* Map<Key, Contents>::next(MapRef& ref) const {
+Contents* Map<Key, Contents>::next(MapRef& ref) {
 //----------------------------====---------
     // durchlaeuft 0-terminierte Liste
     if (ref == 0 ) {
@@ -280,4 +282,6 @@ Contents* Map<Key, Contents>::next(MapRef& ref) const {
     }
 }
 
-#endif
+#endif // _DDD_Map_h
+// DON'T ADD ANYTHING BEHIND THIS #endif
+
