@@ -1,31 +1,33 @@
-// $Id: ScrolleGEP.h,v 1.2 1995/05/02 09:24:00 zeller Exp $  -*- C++ -*-
+// $Id: ScrolleGEP.h,v 1.8 1997/04/25 06:37:27 zeller Exp $  -*- C++ -*-
 // Scrolled Graph Editor (private part)
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with the NORA Library -- see the file COPYING.LIB.
+// License along with the DDD Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// NORA is an experimental inference-based software development
-// environment. Contact nora@ips.cs.tu-bs.de for details.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
-#ifndef __ScrolledGraphEditPrivate_h__
-#define __ScrolledGraphEditPrivate_h__
+#ifndef _DDD_ScrolledGraphEditPrivate_h
+#define _DDD_ScrolledGraphEditPrivate_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -34,7 +36,6 @@
 #include <Xm/Xm.h>
 
 // Superclasses
-extern "C" {
 #define new new_w
 #define class class_w
 #include <Xm/XmP.h>
@@ -42,7 +43,10 @@ extern "C" {
 #include <Xm/ScrolledWP.h>
 #undef new
 #undef class
-}
+
+#ifdef MAX
+#undef MAX			// <Xm/XmP.h> on HP-UX defines this
+#endif
 
 // This class
 #include "ScrolledGE.h"
@@ -82,5 +86,5 @@ typedef struct _ScrolledGraphEditRec {
     ScrolledGraphEditPart sge;
 } ScrolledGraphEditRec;
 
-#endif // __ScrolledGraphEditPrivate_h__
+#endif // _DDD_ScrolledGraphEditPrivate_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
