@@ -1,8 +1,8 @@
-// $Id: TypeInfo.h,v 1.4 1995/05/17 20:31:13 zeller Exp $ -*- C++ -*-
+// $Id: TypeInfo.h,v 1.9 1997/04/25 06:38:07 zeller Exp $ -*- C++ -*-
 // Run-time type information
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
 // This file is part of the ICE Library.
 // 
@@ -19,10 +19,12 @@
 // You should have received a copy of the GNU Library General Public
 // License along with the ICE Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// ICE is the incremental configuration engine.
-// Contact ice@ips.cs.tu-bs.de for details.
+// ICE is the incremental configuration environment.
+// For details, see the ICE World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ice/',
+// or send a mail to the ICE developers at `ice@ips.cs.tu-bs.de'.
 
 #ifndef _ICE_TypeInfo_h
 #define _ICE_TypeInfo_h
@@ -34,6 +36,12 @@
 #include <iostream.h>
 #include <stdlib.h>
 
+#ifdef __GNUC__
+// Set this to 1 to enable TypeInfo table construction at link time
+// instead of run-time (GCC 2.7.0 or lower only)
+// #define IMMEDIATE_TYPE_INFO 1
+#endif
+
 // Use these macros to declare and define type information
 #define DECLARE_TYPE_INFO \
     static TypeInfo type_info; \
@@ -41,7 +49,7 @@
     static BaseList _type_info_all_bases; \
     static const TypeInfo *_type_info_direct_bases[];
 
-#ifdef __GNUG__
+#if IMMEDIATE_TYPE_INFO
 #define _DEFINE_TYPE_INFO(T) \
     TypeInfo T::type_info = \
         { #T, T::_type_info_direct_bases, &T::_type_info_all_bases }; \
@@ -142,8 +150,8 @@ private:
 
 protected:
     // Resources
-    const BaseList direct_bases() const { return _direct_bases; }
-    const BaseList all_bases() const 
+    /* const */ BaseList direct_bases() const { return _direct_bases; }
+    /* const */ BaseList all_bases() const 
     {
 	setup_all_bases();
 	return *_all_bases; 
@@ -156,7 +164,7 @@ protected:
     void makehash();
 
 public:
-#ifndef __GNUG__
+#if !IMMEDIATE_TYPE_INFO
     // Construction
     TypeInfo(char *name, BaseList direct_bases, BaseList *all_bases):
 	_name(name), _direct_bases(direct_bases), _all_bases(all_bases),
