@@ -1,32 +1,34 @@
-// $Id: printBox.h,v 1.3 1995/05/17 18:45:42 zeller Exp $  -*- C++ -*-
+// $Id: printBox.h,v 1.7 1997/04/25 06:40:23 zeller Exp $  -*- C++ -*-
 // definitions for xfig-output - protocol version 2.1
 // comments in /*...*/ taken from xfig-spec-2.1
 
-// Copyright (C) 1993 Technische Universitaet Braunschweig, Germany.
-// Written by Christian Lindig (lindig@ips.cs.tu-bs.de).
+// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Written by Christian Lindig <lindig@ips.cs.tu-bs.de>.
 // 
-// This file is part of the NORA Library.
+// This file is part of the DDD Library.
 // 
-// The NORA Library is free software; you can redistribute it and/or
+// The DDD Library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The NORA Library is distributed in the hope that it will be useful,
+// The DDD Library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 // See the GNU Library General Public License for more details.
 // 
 // You should have received a copy of the GNU Library General Public
-// License along with the NORA Library -- see the file COPYING.LIB.
+// License along with the DDD Library -- see the file COPYING.LIB.
 // If not, write to the Free Software Foundation, Inc.,
-// 675 Mass Ave, Cambridge, MA 02139, USA.
+// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// NORA is an experimental inference-based software development
-// environment. Contact nora@ips.cs.tu-bs.de for details.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.cs.tu-bs.de/softech/ddd/',
+// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.
 
-#ifndef _Nora_printBox_h
-#define _Nora_printBox_h
+#ifndef _DDD_printBox_h
+#define _DDD_printBox_h
 
 /*
 (1) The very first line is a comment line containing the name and version:
@@ -253,5 +255,5 @@
 #define TEXTHEAD1 "4 0 " // +font +font_size
 #define TEXTHEAD2 " 0 -1 0 0.000 4 "
 
-#endif // _Nora_printBox_h
+#endif // _DDD_printBox_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
