@@ -1,5 +1,5 @@
 // This file was modified for -*- C++ -*-
-// using $RCSfile: yacctoC.h,v $ $Revision: 1.3 $
+// using $RCSfile: yacctoC.h,v $ $Revision: 1.6 $
 
 typedef struct _IGNORED_YYSTYPE  {
     // Our special yacctoC program makes this a struct -- 
@@ -12,6 +12,8 @@ typedef struct _IGNORED_YYSTYPE  {
 	struct {
 	    string *id;
 	    VSLNode *pattern;
+	    string *file;
+	    int line;
 	} header;
 	struct {
 	    VSLNode *pattern;
