@@ -1,8 +1,8 @@
-# $Id: yacctoC.h,v 1.3 1995/05/17 18:45:52 zeller Exp $
+# $Id: yacctoC.h,v 1.6 1997/04/25 06:41:19 zeller Exp $
 # Adapt BISON/YACC header output for C++ usage
 
 # Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-# Written by Andreas Zeller (zeller@ips.cs.tu-bs.de).
+# Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 # 
 # This file is part of the ICE Library.
 # 
@@ -19,7 +19,7 @@
 # You should have received a copy of the GNU Library General Public
 # License along with the ICE Library -- see the file COPYING.LIB.
 # If not, write to the Free Software Foundation, Inc.,
-# 675 Mass Ave, Cambridge, MA 02139, USA.
+# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 # 
 # ICE is the incremental configuration engine.
 # Contact ice@ips.cs.tu-bs.de for details.
@@ -27,12 +27,12 @@
 # Declare functions
 1i\
 // This file was modified for -*- C++ -*-\
-// using $RCSfile: yacctoC.h,v $ $Revision: 1.3 $\
+// using $RCSfile: yacctoC.h,v $ $Revision: 1.6 $\
 
 # Make YYSTYPE a struct such that we can store class objects
 # (use anonymous unions to save space!)
 s!^typedef union\(.*\)$!typedef struct _YYSTYPE \1!
 
 # Avoid conflicting re-definitions
-s!YYSTYPE!IGNORED_&!
-s!yylval!IGNORED_&!
+s!YYSTYPE!IGNORED_&!g
+s!yylval!IGNORED_&!g
